@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -170,7 +170,7 @@ _OptionalCreateAppInstanceRequestRequestTypeDef = TypedDict(
     "_OptionalCreateAppInstanceRequestRequestTypeDef",
     {
         "Metadata": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -203,7 +203,7 @@ _OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
     "_OptionalCreateAppInstanceUserRequestRequestTypeDef",
     {
         "Metadata": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
